##  Initiating Calculations on Lifecycle Phase Changes
You can calculate the anticipated resource allocation (such as manpower or financial resources) required for each application based on its lifecycle phase. For example, applications in the Plan or Phase in phase might require more resources due to the need for development or implementation, while applications in the Active phase might require less. Whenever the lifecycle phase changes, you can initiate an automation to calculate resources required for maintenance or decommissioning.
Create an automation where the triggering event is Lifecycle phase change, then select a specific phase. The action is to send a webhook to a target URL. On your automation platform, set up a process to receive this webhook and then calculate the resources required for each phase. Set up the calculation based on your requirements.
